'use client';

import {
  Box,
  Flex,
  Text,
  IconButton,
  Icon,
  Stack,
  Link as ChakraLink,
  Drawer,
  DrawerOverlay,
  DrawerContent,
  DrawerCloseButton,
  DrawerBody,
  useDisclosure,
  HStack,
} from '@chakra-ui/react';
import { MdEmail, MdMenu } from 'react-icons/md';
import Link from 'next/link';
import CButton from '../ui/CButton';
import { navItems } from '@/app/constants/navItems';
import {  Modal, ModalOverlay, ModalContent, ModalHeader, ModalCloseButton, ModalBody } from '@chakra-ui/react';
import NewsletterSignup from '../NewsletterSignup';

export default function Navbar() {
  const { isOpen, onOpen, onClose } = useDisclosure();
const { isOpen: isNewsletterOpen, onOpen: onNewsletterOpen, onClose: onNewsletterClose } = useDisclosure();

  return (
    <Box as="header" width="100%" bg="black" color="white" shadow="sm">
      {/* Newsletter Banner */}
    <Flex
  bg="gray.900"
  py={2}
  px={4}
  align="center"
  justify="center"
  gap={2}
  cursor="pointer"
  onClick={onNewsletterOpen}
>
  <Icon as={MdEmail} boxSize={5} color="teal.300" />
  <Text fontSize="sm" color="gray.200">
    Subscribe to our Newsletter for New & Latest Blogs and Resources
  </Text>
</Flex>

{/* Newsletter Signup Modal */}
<Modal isOpen={isNewsletterOpen} onClose={onNewsletterClose} isCentered>
  <ModalOverlay />
  <ModalContent borderRadius="xl" mx={4}>
    <ModalHeader>Subscribe to our Newsletter</ModalHeader>
    <ModalCloseButton />
   <ModalBody pb={6}>
  <NewsletterSignup onClose={onNewsletterClose} />
</ModalBody>

  </ModalContent>
</Modal>

      {/* Main Navbar */}
      <Flex
        py={4}
        px={{ base: 4, md: 10 }}
        align="center"
        justify="space-between"
      >
        {/* Logo */}
        <Text fontSize="xl" fontWeight="bold" color="white">
          ✨ Tema&apos;s Blog
        </Text>

        {/* Hamburger Menu Button (mobile only) */}
        <IconButton
          aria-label="Open menu"
          icon={<MdMenu />}
          display={{ base: 'flex', md: 'none' }}
          onClick={onOpen}
          color="white"
          bg="transparent"
          _hover={{ bg: 'gray.700' }}
        />

        {/* Center Menu (desktop only) */}
        <Stack
          direction="row"
          spacing={8}
          display={{ base: 'none', md: 'flex' }}
        >
          {navItems.map((item) => (
            <ChakraLink
              as={Link}
              href={item.href}
              key={item.label}
              fontSize="md"
              fontWeight="medium"
              _hover={{ color: 'teal.300' }}
            >
              {item.label}
            </ChakraLink>
          ))}
        </Stack>

        {/* CTA Buttons (desktop only) */}
        <Box display={{ base: 'none', md: 'block' }}>
          <HStack spacing={4}>
            <Link href="/share-experience">
              <CButton>Share Experience</CButton>
            </Link>
            <CButton onClick={() => console.log('clicked')}>
              Contact Us
            </CButton>
          </HStack>
        </Box>
      </Flex>

      {/* Drawer for Mobile Menu */}
      <Drawer placement="left" onClose={onClose} isOpen={isOpen}>
        <DrawerOverlay />
        <DrawerContent bg="black" color="white">
          <DrawerCloseButton />
          <DrawerBody>
            <Stack spacing={6} mt={10}>
              {navItems.map((item) => (
                <ChakraLink
                  as={Link}
                  href={item.href}
                  key={item.label}
                  fontSize="lg"
                  fontWeight="bold"
                  onClick={onClose}
                  _hover={{ color: 'teal.300' }}
                >
                  {item.label}
                </ChakraLink>
              ))}

              {/* CTA Buttons for mobile */}
              <Link href="/share-experience">
                <CButton
                  bgGradient="linear(to-r, pink.400, orange.300)"
                  color="white"
                  _hover={{
                    transform: 'scale(1.05)',
                    boxShadow: '0 0 0 3px rgba(255, 192, 203, 0.5)',
                  }}
                  _active={{
                    transform: 'scale(0.95)',
                  }}
                  transition="all 0.3s ease-in-out"
                >
                  Share Experience
                </CButton>
              </Link>





              <Link href="/contact" passHref>
                <CButton
                  bgGradient="linear(to-r, pink.400, orange.300)"
                  color="white"
                  _hover={{
                    transform: 'scale(1.05)',
                    boxShadow: '0 0 0 3px rgba(255, 192, 203, 0.5)',
                  }}
                  _active={{
                    transform: 'scale(0.95)',
                  }}
                  transition="all 0.3s ease-in-out"
                >
                  Contact Us
                </CButton>
              </Link>
            </Stack>
          </DrawerBody>
        </DrawerContent>
      </Drawer>
    </Box>
  );
}
